==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/eu.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Pasahitza 1000000 pasahitz tipikoen taldean dago. Unikoa bihur ezazu",
    "Password is present in compromised password list. Please choose a different password." : "Pasahitz hau ezaguna den pasahitzen fitxategi baten dago. Aukeratu beste bat.",
    "Password needs to be at least %s characters long" : "Pasahitzak %s karaktere izan behar du gutxienez",
    "Password needs to contain at least one numeric character." : "Pasahitzek zenbaki bat izan behar dute gutxienez.",
    "Password needs to contain at least one special character." : "Pasahitzek karaktere berezi bat izan behar dute gutxienez.",
    "Password needs to contain at least one lower and one upper case character." : "Pasahitzek hizki xehe eta hizki larri bat izan behar du gutxienez.",
    "Password policy" : "Pasahitz politika",
    "Allows admins to configure a password policy" : "Baimendu administratzaileei pasahitzen politika bat konfiguratzea",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Baimendu kudeatzaileari pasahitzen inguruko baldintzak ezartze, adb: luzera minimo bat izatera derrigortu.",
    "Minimal length" : "Luzera minimoa",
    "User password history" : "Erabiltzailearen pasahitz historia",
    "Forbid common passwords" : "Pasahitz ohikoenak debekatu",
    "Enforce upper and lower case characters" : "Enforce upper and lower case characters",
    "Enforce numeric characters" : "Karaktere numerikoak destakatu",
    "Enforce special characters" : "Karaktere bereziak destakatu",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Pasahitzak haveibeenpwned.com zerbitzuan egiaztatu",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Egiaztapenak pasahitzaren hash bat sortzen du eta lehenengo bost karaktereak haveibeenpwned.com zerbitzuaren APIra bidaltzen ditu berdin hasten diren hashak lortzeko. Ondoen Nextcloud instantzia barruan egiaztatzen du idatzitako pasahitzaren hasha zerrenda horretan dagoen ala.ez"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/eu.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Pasahitza iraungi egin da, berrezartzeko erabili pasahitza ahaztu izanaren metodoa",
    "Password must not have been used recently before." : "Pasahitzak azkenaldian erabili gabea izan behar du.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Pasahitza 1000000 pasahitz tipikoen taldean dago. Unikoa bihur ezazu",
    "Password is present in compromised password list. Please choose a different password." : "Pasahitz hau ezaguna den pasahitzen fitxategi baten dago. Aukeratu beste bat.",
    "Password needs to be at least %s characters long" : "Pasahitzak %s karaktere izan behar du gutxienez",
    "Password needs to contain at least one numeric character." : "Pasahitzek zenbaki bat izan behar dute gutxienez.",
    "Password needs to contain at least one special character." : "Pasahitzek karaktere berezi bat izan behar dute gutxienez.",
    "Password needs to contain at least one lower and one upper case character." : "Pasahitzek hizki xehe eta hizki larri bat izan behar du gutxienez.",
    "Password policy" : "Pasahitz politika",
    "Allows admins to configure a password policy" : "Baimendu administratzaileei pasahitzen politika bat konfiguratzea",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Baimendu kudeatzaileari pasahitzen inguruko baldintzak ezartze, adb: luzera minimo bat izatera derrigortu.",
    "Minimal length" : "Luzera minimoa",
    "User password history" : "Erabiltzailearen pasahitz historia",
    "days until user password expires" : "erabiltzailearen pasahitza iraungi arteko egunak",
    "login attempts before the user account is blocked. (0 for no limit)" : "saio-haste saiakera kopurua erabiltzaile kontua blokeatu aurretik. (0 mugarik ez ezartzeko)",
    "Forbid common passwords" : "Pasahitz ohikoenak debekatu",
    "Enforce upper and lower case characters" : "Enforce upper and lower case characters",
    "Enforce numeric characters" : "Karaktere numerikoak destakatu",
    "Enforce special characters" : "Karaktere bereziak destakatu",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Pasahitzak haveibeenpwned.com zerbitzuan egiaztatu",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Egiaztapenak pasahitzaren hash bat sortzen du eta lehenengo bost karaktereak haveibeenpwned.com zerbitzuaren APIra bidaltzen ditu berdin hasten diren hashak lortzeko. Ondoen Nextcloud instantzia barruan egiaztatzen du idatzitako pasahitzaren hasha zerrenda horretan dagoen ala.ez"
},
"nplurals=2; plural=(n != 1);");
